@@ -8,15 +8,18 @@ from pype import traversals
 registry = plug.Registry()
 
 
-def calculate_function(traversal, autocall=None):
-    if autocall is None:
-        autocall = traversal.global_invocation_options.global_options["autocall"]
-
+def calculate_function(traversal, howcall=None):
+    if howcall is None:
+        howcall = traversal.specific_invocation_params.get("howcall")
+    if howcall is None:
+        howcall = interpret.HowCall.SINGLE
     return {
         "function": interpret.build_function(
             traversal.specific_invocation_params["pipeline"],
-            traversal.global_invocation_options.global_options["global_namespace"],
-            autocall,
+            global_namespace=traversal.global_invocation_options.global_options[
+                "global_namespace"
+            ],
+            howcall=howcall,
         )
     }
 
@@ -26,7 +29,7 @@ def calculate_reduce(traversal):
     function = interpret.build_function(
         traversal.specific_invocation_params["pipeline"],
         traversal.global_invocation_options.global_options["global_namespace"],
-        autocall=interpret.HowCall.VARARGS,
+        howcall=interpret.HowCall.VARARGS,
     )
 
     return {"function": function}
@@ -80,7 +83,7 @@ async def aapply(function, items):
 @registry.add_traversal(
     "eval",
     calculate_more_params=lambda x: calculate_function(
-        x, autocall=interpret.HowCall.NONE
+        x, howcall=interpret.HowCall.NONE
     ),
 )
 async def eval(function):
@@ -116,7 +119,6 @@ subcommands = [
         "afilter",
         short_help="Async call <pipeline> on each line of input and exclude false values.",
     ),
-    click.Command("eval", short_help="Call <pipeline> without any input."),
     click.Command(
         "stack", short_help="Call <pipeline> on input as a single concatenated string."
     ),
@@ -128,14 +130,30 @@ subcommands = [
 
 
 def build_callback(sub_command):
-    def callback(pipeline):
-        return [{"name": sub_command.name.replace("-", "_"), "pipeline": pipeline}]
+    def callback(pipeline, autocall, **kwargs):
+        if autocall:
+            howcall = interpret.HowCall.SINGLE
+        else:
+            howcall = interpret.HowCall.NONE
+
+        return [
+            {
+                "name": sub_command.name.replace("-", "_"),
+                "howcall": howcall,
+                "pipeline": pipeline,
+                **kwargs,
+            }
+        ]
 
     return callback
 
 
 for subcommand in subcommands:
-    subcommand.params = [click.Argument(["pipeline"])]
+
+    subcommand.params = [
+        click.Option(["--autocall/--no-autocall"], is_flag=True, default=True),
+        click.Argument(["pipeline"]),
+    ]
     subcommand.callback = build_callback(subcommand)
     # TODO: add_cli and add_traversal should be the non-decorator form
     registry.add_cli(name=subcommand.name)(subcommand)
@@ -148,3 +166,10 @@ for subcommand in subcommands:
 @click.argument("function_name")
 def _reduce(function_name):
     return [{"pipeline": f"toolz.curry({function_name})", "name": "reduce"}]
+
+
+@registry.add_cli(name="eval")
+@click.command("eval", short_help="Call <pipeline> without any input.")
+@click.argument("expression")
+def _eval(expression):
+    return [{"pipeline": expression, "name": "eval"}]
